Welcome to Shaker!
==================

**The distributed data-plane testing tool built for OpenStack.**

Shaker wraps around popular system network testing tools like
`iperf <https://iperf.fr/>`_, `iperf3 <https://iperf.fr/>`_
and netperf (with help of `flent <https://flent.org/>`_).
Shaker is able to deploy OpenStack instances and networks in different
topologies. Shaker scenario specifies the deployment and list of tests
to execute. Additionally tests may be tuned dynamically in command-line.

.. toctree::
    :maxdepth: 2

    installation
    usage
    architecture
    tools
    catalog
    examples/index
    examples_spot
    reports/index
    config
    contributing
